<!--suppress LongLine -->
<div align="center">
  <a href="https://marsho.liteyuki.org"><img src="https://marsho.liteyuki.org/marsho-full.svg" width="800" height="430" alt="MarshoLogo"></a>
  <br>
</div>

<div align="center">

# nonebot-plugin-marshoai

_✨ 使用 OpenAI 标准格式 API 的聊天机器人插件 ✨_  

[![QQ群](https://img.shields.io/badge/QQ群-1029557452-blue.svg?logo=QQ&style=flat-square)](https://qm.qq.com/q/a13iwP5kAw)
[![NoneBot Registry](https://img.shields.io/endpoint?url=https%3A%2F%2Fnbbdg.lgc2333.top%2Fplugin%2Fnonebot-plugin-marshoai&style=flat-square)](https://registry.nonebot.dev/plugin/nonebot-plugin-marshoai:nonebot_plugin_marshoai)
<a href="https://registry.nonebot.dev/plugin/nonebot-plugin-marshoai:nonebot_plugin_marshoai">
  <img src="https://img.shields.io/endpoint?url=https%3A%2F%2Fnbbdg.lgc2333.top%2Fplugin-adapters%2Fnonebot-plugin-marshoai&style=flat-square" alt="Supported Adapters">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-marshoai">
  <img src="https://img.shields.io/pypi/v/nonebot-plugin-marshoai.svg?style=flat-square" alt="pypi">
</a>
  <img src="https://img.shields.io/badge/python-3.10+-blue.svg?style=flat-square" alt="python">
  <img src="https://img.shields.io/badge/Code%20Style-Black-121110.svg?style=flat-square" alt="codestyle">
</div>  

<img width="100%" src="https://starify.komoridevs.icu/api/starify?owner=LiteyukiStudio&repo=nonebot-plugin-marshoai" alt="starify" />

## 📖 介绍

通过调用 OpenAI 标准格式 API（例如 GitHub Models API），来实现聊天的插件。  
插件内置了猫娘小棉（Marsho，マルショ）的人物设定，可以进行可爱的聊天！  
_谁不喜欢回复消息快又可爱的猫娘呢？_  
**对 OneBot 以外的适配器与非 GitHub Models API 的支持未完全经过验证。**  
[Melobot 实现](https://github.com/LiteyukiStudio/marshoai-melo)

## 🐱 设定

#### 基本信息

-   名字：小棉（Marsho，マルショ）
-   生日：9 月 6 日

#### 喜好

-   🌞 晒太阳晒到融化
-   🤱 撒娇啊～谁不喜欢呢～
-   🍫 吃零食！肉肉好吃！
-   🐾 玩！我喜欢和朋友们一起玩！

## 😼 使用

请查看[使用文档](https://marsho.liteyuki.org/start/use.html)

## ❤ 鸣谢&版权说明

> Copyright (c) 2025 Asankilp & LiteyukiStudio

本项目使用了以下项目的代码：

-   [nonebot-plugin-latex](https://github.com/EillesWan/nonebot-plugin-latex)
-   [nonebot-plugin-deepseek](https://github.com/KomoriDev/nonebot-plugin-deepseek)

"Marsho" logo 由 [@Asankilp](https://github.com/Asankilp) 绘制，基于 [CC BY-NC-SA 4.0](http://creativecommons.org/licenses/by-nc-sa/4.0/) 许可下提供。  
"nonebot-plugin-marshoai" 基于 [MIT](./LICENSE-MIT) 许可下提供。  
部分指定的代码基于 [Mulan PSL v2](./LICENSE-MULAN) 许可下提供。

<div>
  <a href="https://github.com/LiteyukiStudio/nonebot-plugin-marshoai/graphs/contributors">
    <img src="https://contrib.rocks/image?repo=LiteyukiStudio/nonebot-plugin-marshoai" alt="Contributors">
  </a>
</div>

感谢所有的贡献者！

## 开发

-   请阅读[开发规范](./README_DEV.md)
